'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _airtable = require('airtable');

var _airtable2 = _interopRequireDefault(_airtable);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const ENDPOINT_URL = 'https://api.airtable.com';
let API_KEY; // Can only set the API key once per program

class AirTable {

    constructor({ apiKey, databaseRef }) {
        if (!API_KEY) {
            API_KEY = apiKey;
            _airtable2.default.configure({
                endpointUrl: ENDPOINT_URL,
                apiKey: globalApiKey
            });
        }
        this.base = _airtable2.default.base(databaseRef);

        this.get = {
            single: this.getSingleRecordFrom.bind(this),
            all: this.getAllRecordsFrom.bind(this),
            match: this.getAllMatchedRecordsFrom.bind(this),
            select: this.getRecordsSelect.bind(this)
        };
    }

    async getSingleRecordFrom({ tableName, id }) {
        console.log(tableName, id);
        return new Promise((resolve, reject) => {
            this.base(tableName).find(id, function (err, record) {
                if (err) {
                    console.error(err);
                    reject(err);
                }
                resolve(record);
            });
            // console.log(record);
        });
    }

    async getAllRecordsFrom(tableName) {
        return this.getRecordsSelect({ tableName, select: {} });
    }

    async getAllMatchedRecordsFrom({ tableName, column, value }) {
        return this.getRecordsSelect({ tableName, select: { filterByFormula: `${column} = ${value}` } }); // TODO: validate input
    }

    async getRecordsSelect({ tableName, select }) {
        return new Promise((resolve, reject) => {
            let out = [];
            this.base(tableName).select(select).eachPage((records, fetchNextPage) => {
                // Flatten single entry arrays, need to remove this hacky shit.
                _lodash2.default.map(records, r => {
                    _lodash2.default.forOwn(r.fields, (value, key) => {
                        // If array is single
                        if (_lodash2.default.isArray(value) && value.length == 1 && key != 'rooms') {
                            r.fields[key] = value[0];
                        }
                    });
                });
                out = _lodash2.default.concat(out, records);
                fetchNextPage();
            }, err => {
                if (err) {
                    console.error(err);
                    reject(err);
                } else {
                    // console.log(JSON.stringify(out, null, 4))
                    // console.log("HI")
                    resolve(out);
                }
            });
        });
    }
}
exports.default = AirTable;
